@@ -1,3 +1,26 @@
+/*
+ * Copyright Scott Balneaves, sbalneav@ltsp.org, 2007, 2008
+ *           Vagrant Cascadian, vagrant@freegeek.org, 2008
+ *           Gideon Romm, gadi@ltsp.org, 2009
+
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, you can find it on the World Wide
+ * Web at http://www.gnu.org/copyleft/gpl.html, or write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+
+ */
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -27,7 +50,7 @@ char *device;
  */
 
 gboolean
-check_cd_status()
+check_cd_status(void)
 {
     char dev[BUFSIZ], cmd[BUFSIZ];
     int cdrom, status;
@@ -88,7 +111,7 @@ check_cd_status()
         case CDS_DISC_OK:
             if (last == CDP_CDROM_UMOUNT) {
                 snprintf(cmd, sizeof cmd,
-                        "/lib/udev/ltspfs_entry add %s auto", device);
+                        "/lib/udev/ltspfs_entry add %s iso9660", device);
                 last = CDP_CDROM_MOUNT;
                 return g_spawn_command_line_sync(cmd, NULL, NULL, NULL, NULL);
             }
