@@ -2,9 +2,24 @@
  * ltspfs: a FUSE module for implementing a diskless thin client filesysem
  * to be used for local device access.
  *
- * Copyright 2005, Scott Balneaves
- * This file is licensed under the GNU GPL.  Please see the "Copying" file
- * for details.
+ * Copyright Scott Balneaves, sbalneav@ltsp.org, 2005, 2006, 2007
+
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, you can find it on the World Wide
+ * Web at http://www.gnu.org/copyleft/gpl.html, or write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+
  */
 
 #include <stdio.h>
@@ -61,7 +76,7 @@ void init_pkt(XDR * in, XDR * out, char *inbuf, char *outbuf)
  * This will improve over time, retry's are a possibility, etc.
  */
 
-void timeout()
+void timeout(void)
 {
     close(sockfd);
     fuse_unmount(fuse_mount_point);
@@ -207,7 +222,7 @@ static int parse_return(XDR * xdr)
  * side.
  */
 
-int ltspfs_sendauth()
+int ltspfs_sendauth(void)
 {
     XDR in, out;
     char inbuf[LTSP_MAXBUF];
